pub enum AnnotationScope {
Statement,
Sender,
Receiver,
}Expand description
Scope for one collected annotation record.
Variants
Statement
Annotation attached to the statement itself.
Sender
Annotation attached to the sender side of a statement.
Receiver
Annotation attached to the receiver side of a statement.